@@ -1,5 +1,5 @@
 from mimetypes import guess_extension
-from os import environ
+from shutil import rmtree
 
 import click
 
@@ -83,7 +83,7 @@ def save_needed(problem, submissions, sub_dir, session, full_sync):
 def sync_code(problem, task_dir, submissions, session, full_sync):
     sub_dir = task_dir / 'submissions'
     if sub_dir.exists():
-        if not task_dir.is_dir():
+        if not sub_dir.is_dir():
             click.secho(f'File {sub_dir.relative_to(find_workspace())} exists, skipping',
                         fg='red', err=True)
             return
@@ -94,6 +94,35 @@ def sync_code(problem, task_dir, submissions, session, full_sync):
         save_needed(problem, problem_subs, sub_dir, session, full_sync)
 
 
+def sync_attachments(problem, dest_dir, session):
+    attachments = problem.attachments()
+    dest_dir_exists = dest_dir.exists()
+    if dest_dir_exists and not dest_dir.is_dir():
+        if attachments:
+            click.secho(
+                f'File {dest_dir.relative_to(find_workspace())} exists, '
+                'skipping attachment sync',
+                fg='red', err=True
+            )
+        # Don't warn if the attachment list is empty
+        return
+
+    if dest_dir_exists:
+        # If an attachment was removed from the statement, it should be deleted.
+        # Remove all attachments, existing ones will be resynced anyway.
+        rmtree(dest_dir)
+
+    if not attachments:
+        return
+
+    dest_dir.mkdir(parents=True, exist_ok=True)
+    for att_name, url in attachments.items():
+        att_path = dest_dir / att_name
+        page = session.get(url)
+        with att_path.open('wb') as f:
+            f.write(page.content)
+
+
 @click.command(short_help='Parse problems from ejudge', cls=OptFlagCommand)
 @click.option('--code', cls=FlagOption, is_flag=True,
               help='Download latest submitted solutions')
@@ -112,7 +141,10 @@ def sync(code, code_opt, force, filters):
     workspace = find_workspace()
 
     if workspace is None:
-        click.secho('You have to run sync under kks workspace (use "kks init" to create one)', fg='red', err=True)
+        click.secho(
+            'You have to run sync under kks workspace (use "kks init" to create one)',
+            fg='red', err=True
+        )
         return
 
     config = Config()
@@ -151,16 +183,24 @@ def sync(code, code_opt, force, filters):
             continue
 
         if not task_dir.exists():
-            click.secho('Creating directories for task ' + click.style(problem.name, fg='blue', bold=True))
+            click.secho(
+                'Creating directories for task ' + click.style(problem.name, fg='blue', bold=True)
+            )
             task_dir.mkdir(parents=True, exist_ok=True)
         else:
             if not task_dir.is_dir():
-                click.secho(f'File {task_dir.relative_to(workspace)} exists, skipping', fg='red', err=True)
+                click.secho(
+                    f'File {task_dir.relative_to(workspace)} exists, skipping',
+                    fg='red', err=True
+                )
                 continue
 
             if not force:
                 if code:
-                    click.secho('Syncing submissions for ' + click.style(problem.name, fg='blue', bold=True))
+                    click.secho(
+                        'Syncing submissions for ' +
+                        click.style(problem.name, fg='blue', bold=True)
+                    )
                     sync_code(problem, task_dir, submissions, session, code_all)
                     new_problems += 1
                 else:
@@ -194,9 +234,11 @@ def sync(code, code_opt, force, filters):
 
         html_statement_path = task_dir / 'statement.html'
         md_statement_path = task_dir / 'statement.md'
+        attachments_path = task_dir / 'attachments'
 
         if config.options.save_html_statements:
-            if problem.statement_available() or not html_statement_path.exists():  # overwrite only if statement is available
+            # overwrite only if statement is available
+            if problem.statement_available() or not html_statement_path.exists():
                 with html_statement_path.open('w') as f:
                     f.write(problem.html())
         elif html_statement_path.is_file():
@@ -209,13 +251,19 @@ def sync(code, code_opt, force, filters):
         elif md_statement_path.is_file():
             md_statement_path.unlink()
 
+        if config.options.save_attachments:
+            if problem.statement_available():
+                sync_attachments(problem, attachments_path, session)
+        elif attachments_path.is_dir():
+            rmtree(attachments_path)
+
         if problem.input_data is not None:
             with (tests_dir / '000.in').open('w') as f:
                 f.write(problem.input_data)
 
         if problem.output_data is not None:
             with (tests_dir / '000.out').open('w') as f:
-                f.write(problem.output_data + '\n')
+                f.write(problem.output_data)
 
         if code:
             click.secho('Syncing submissions')
@@ -225,4 +273,7 @@ def sync(code, code_opt, force, filters):
 
     color = 'green' if old_problems + new_problems == total_problems else 'red'
     click.secho('Sync done!', fg='green')
-    click.secho(f'Synced tasks: {old_problems+new_problems}/{total_problems} ({old_problems} unchanged)', fg=color)
+    click.secho(
+        f'Synced tasks: {old_problems+new_problems}/{total_problems} ({old_problems} unchanged)',
+        fg=color
+    )
