@@ -70,7 +70,7 @@ class EnvSection(Section):
 
     def __getattribute__(self, key):
         if not super().__getattribute__('_is_option')(key):
-            return super().__getattribute__(key)  # how to avoid second check?
+            return super(Section, self).__getattribute__(key)
 
         envvar = environ.get(EnvSection.to_envvar(key))
         if envvar is not None:
@@ -87,6 +87,7 @@ class AuthSection(Section):
 class OptionsSection(EnvSection):
     save_html_statements: bool = True
     save_md_statements: bool = True
+    save_attachments: bool = True
     mdwidth: int = 100
     max_kr: bool = False
     deadline_warning_days: int = 1
@@ -187,11 +188,17 @@ class PickleStorage:
                     if click.confirm(click.style('Erase all saved data?', fg='red', bold=True)):
                         self._init_data(False)
                     else:
-                        click.secho(f'You need to fix or delete {self._file.absolute()} manually', fg='red', err=True)
+                        click.secho(
+                            f'You need to fix or delete {self._file.absolute()} manually',
+                            fg='red', err=True
+                        )
                         sys.exit()
 
         if self._data['__version__'] != self._version:
-            click.secho(f'{self._file} uses an incompatible storage version, clearing saved data', bg='red', err=True)
+            click.secho(
+                f'{self._file} uses an incompatible storage version, clearing saved data',
+                bg='red', err=True
+            )
             self._init_data(False)
         return self
 
